@@ -104,6 +104,7 @@ AddOn.prototype.initAddOn = function(splash, text) {
 
     var initFilePath = this.getInitFilePath();
     if (new QFileInfo(initFilePath).exists()) {
+        // include Init file of action (e.g. MyActionInit.js) and call global init function:
         include(initFilePath, className, true);
         init(includeBasePath);
     }
@@ -198,7 +199,7 @@ AddOn.prototype.initPreferencePage = function() {
         WidgetFactory.restoreState(widget);
         WidgetFactory.saveState(widget);
         WidgetFactory.requiresRestart = false;
-        widget.destroy();
+        destr(widget);
 
         RSettings.setValue(settingsKey, true);
     }
