@@ -58,6 +58,13 @@ InsertScriptItem.prototype.beginEvent = function() {
     }
 
     this.file = this.url.toLocalFile();
+
+    // sanity checks:
+    if (!InsertScriptItem.check(this.file)) {
+        this.terminate();
+        return;
+    }
+
     include(this.file);
     
     InsertScriptItem.evalInit(this.file);
@@ -67,13 +74,51 @@ InsertScriptItem.prototype.beginEvent = function() {
     this.setState(InsertBlockItem.State.SettingPosition);
 };
 
+/**
+ * Sanity check before including a script.
+ * \return true if this is very likely a part library script item.
+ */
+InsertScriptItem.check = function(fileName) {
+    var baseName = new QFileInfo(fileName).baseName();
+    var content = readTextFile(fileName);
+    if (isNull(content)) {
+        EAction.handleUserWarning(qsTr("Cannot read file:") + " " + fileName);
+        return false;
+    }
+
+    if (!content.contains("function " + baseName)) {
+        EAction.handleUserWarning(qsTr("No constructor found in file:") + " " + fileName);
+        return false;
+    }
+
+    if (!content.contains(baseName + ".init")) {
+        EAction.handleUserWarning(qsTr("No 'init' function found in file:") + " " + fileName);
+        return false;
+    }
+
+    if (!content.contains(baseName + ".generate")) {
+        EAction.handleUserWarning(qsTr("No 'generate' function found in file:") + " " + fileName);
+        return false;
+    }
+
+    if (!content.contains(baseName + ".generatePreview")) {
+        EAction.handleUserWarning(qsTr("No 'generatePreview' function found in file:") + " " + this.file);
+        return false;
+    }
+
+    return true;
+};
+
 InsertScriptItem.prototype.finishEvent = function() {
-    var dock = objectFromPath("MainWindow::"
-            + InsertScriptItem.getObjectName(this.file));
+    var dock = objectFromPath("MainWindow::" + InsertScriptItem.getObjectName(this.file));
     if (!isNull(dock)) {
         dock.hide();
-        dock.destroy();
+        destr(dock);
     }
+    if (!isNull(this.diItem)) {
+        destr(this.diItem);
+    }
+
     InsertBlockItem.prototype.finishEvent.call(this);
 };
 
