@@ -3,12 +3,10 @@ function init(basePath) {
     action.setRequiresDocument(true);
     action.setScriptFile(basePath + "/SelectBlockReferences.js");
     action.setIcon(basePath + "/SelectBlockReferences.svg");
-    //action.setDefaultShortcut(new QKeySequence("b,+"));
     action.setDefaultShortcuts([
-                            new QKeySequence("b,+"),
-                            new QKeySequence("b,[")
+                            new QKeySequence("b,k")
                         ]);
-    action.setDefaultCommands(["blockselect", "selectblock", "b+"]);
+    action.setDefaultCommands(["blockselect", "selectblock", "bk"]);
     action.setGroupSortOrder(14400);
     action.setSortOrder(100);
     action.setWidgetNames(["BlockMenu", "BlockToolBar", "BlockToolsPanel", "BlockMatrixPanel"]);
