@@ -148,9 +148,12 @@ EAction.prototype.finishEvent = function() {
     // reset CAD tool bar:
     if (!isNull(guiAction) && guiAction.getGroup() === "") {
         var appWin = EAction.getMainWindow();
-        var cadToolBar = appWin.findChild("CadToolBar");
-        if (!isNull(cadToolBar) && cadToolBar.getCurrentPanelName()==="SnapToolsPanel") {
-            cadToolBar.back();
+        if (!isNull(appWin)) {
+            // appWin can be NULL if it is being deleted
+            var cadToolBar = appWin.findChild("CadToolBar");
+            if (!isNull(cadToolBar) && cadToolBar.getCurrentPanelName()==="SnapToolsPanel") {
+                cadToolBar.back();
+            }
         }
     }
 
@@ -794,6 +797,16 @@ EAction.prototype.setCursor = function(cursor, name) {
     if (!isNull(di)) {
         di.setCursor(cursor);
     }
+    var appWin = EAction.getMainWindow();
+    if (!isNull(appWin)) {
+        if (isNull(name)) {
+            appWin.setProperty("MouseCursor", "");
+        }
+        else {
+            appWin.setProperty("MouseCursor", name);
+        }
+    }
+
 //    if (!isNull(name)) {
 //        var views = this.getGraphicsViews();
 //        for (var i=0; i<views.length; i++) {
@@ -992,7 +1005,8 @@ EAction.getMenu = function(title, objectName, initFunction) {
     if (isNull(menu)) {
         menu = new QMenu(title, menuBar);
         menu.objectName = objectName;
-        menuBar.addMenu(menu);
+        var action = menuBar.addMenu(menu);
+        action.objectName = objectName + "Action";
         if (initFunction != undefined) {
             initFunction(menu);
         }
@@ -1844,9 +1858,7 @@ EAction.prototype.simulateMouseMoveEvent = function() {
         return;
     }
 
-    if (isFunction(view.getRGraphicsView)) {
-        view = view.getRGraphicsView();
-    }
+    view = getRGraphicsView(view);
 
     if (isNull(view)) {
         return;
@@ -2199,6 +2211,7 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
         a = menu.addAction(str);
         if (!isNull(icon)) {
             a.icon = icon;
+            a.iconVisibleInMenu = true;
         }
 
         reactor = new Reactor(id);
@@ -2208,12 +2221,9 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
 
     // show context menu:
     if (!menu.isEmpty()) {
-        var prev = QCoreApplication.testAttribute(Qt.AA_DontShowIconsInMenus);
-        QCoreApplication.setAttribute(Qt.AA_DontShowIconsInMenus, false);
         this.waitingForContextMenu = true;
         menu.exec(new QPoint(QCursor.pos().x(), QCursor.pos().y()+10));
         this.waitingForContextMenu = false;
-        QCoreApplication.setAttribute(Qt.AA_DontShowIconsInMenus, prev);
         di.clearPreview();
     }
 
