@@ -40,7 +40,9 @@ LanguagePreferences.localLanguageName["hu"] = "Magyar";
 LanguagePreferences.localLanguageName["hr"] = "Hrvatski";
 LanguagePreferences.localLanguageName["it"] = "Italiano";
 LanguagePreferences.localLanguageName["ja"] = "日本語";
+LanguagePreferences.localLanguageName["ko"] = "한국어";
 LanguagePreferences.localLanguageName["lt"] = "Lietuvių kalba";
+LanguagePreferences.localLanguageName["nb"] = "Norsk";
 LanguagePreferences.localLanguageName["nl"] = "Nederlands";
 LanguagePreferences.localLanguageName["pl"] = "Polski";
 LanguagePreferences.localLanguageName["pt"] = "Português";
@@ -50,8 +52,10 @@ LanguagePreferences.localLanguageName["sk"] = "Slovenčina";
 LanguagePreferences.localLanguageName["sl"] = "Slovenščina";
 LanguagePreferences.localLanguageName["sv"] = "Svenska";
 LanguagePreferences.localLanguageName["tr"] = "Türkçe";
+LanguagePreferences.localLanguageName["uk"] = "Українська";
 LanguagePreferences.localLanguageName["zh_TW"] = "繁體中文";
-LanguagePreferences.localLanguageName["zh_ZN"] = "简体中文";
+LanguagePreferences.localLanguageName["zh"] = "简体中文";
+LanguagePreferences.localLanguageName["zh_CN"] = "简体中文";
 
 LanguagePreferences.getPreferencesCategory = function() {
     return [qsTr("Language Settings"), qsTr("Language")];
@@ -69,16 +73,16 @@ LanguagePreferences.initPreferences = function(pageWidget, calledByPrefDialog, d
     }
     language.model().sort(0);
     
-    if (RSettings.getQtVersion() >= 0x060000) {
-        language.currentTextChanged.connect(this, function(text) {
-            RSettings.setValue("LibraryBrowser/RebuildDatabase", true);
-        });
-    }
-    else {
-        language["currentIndexChanged(QString)"].connect(this, function(text) {
-            RSettings.setValue("LibraryBrowser/RebuildDatabase", true);
-        });
-    }
+//    if (RSettings.getQtVersion() >= 0x060000) {
+//        language.currentTextChanged.connect(this, function(text) {
+//            RSettings.setValue("LibraryBrowser/RebuildDatabase", true);
+//        });
+//    }
+//    else {
+//        language["currentIndexChanged(QString)"].connect(this, function(text) {
+//            RSettings.setValue("LibraryBrowser/RebuildDatabase", true);
+//        });
+//    }
 
     
 //  var contents = pageWidget.findChild("LanguagePage");
