@@ -18,9 +18,9 @@
  */
 
 include("scripts/File/File.js");
-include("../Save/Save.js");
+include("scripts/File/Save/Save.js");
 include("scripts/Widgets/ViewportWidget/ViewportWidget.js");
-include("../AutoSave/AutoSave.js");
+include("scripts/File/AutoSave/AutoSave.js");
 include("scripts/Reset/Reset.js");
 
 if (exists("scripts/DefaultAction.js")) {
@@ -118,12 +118,15 @@ NewFile.prototype.beginEvent = function() {
  * \param uiFile UI file to use for view port (defaults to ViewportWidgetQt.ui).
  * \param graphicsSceneClass Class to use for graphics scene (defaults to "RGraphicsSceneQt")
  */
-NewFile.createMdiChild = function(fileName, nameFilter, uiFile, graphicsSceneClass) {
+NewFile.createMdiChild = function(fileName, nameFilter, uiFile, graphicsSceneClass, silent) {
     var isOpen = !isNull(fileName);
 
     if (isNull(nameFilter)) {
         nameFilter = "";
     }
+    if (isNull(silent)) {
+        silent = false;
+    }
 
     if (isOpen && !isUrl(fileName)) {
         if (!isNull(AutoSave) && !new QFileInfo(fileName).baseName().startsWith("~")) {
@@ -159,13 +162,17 @@ NewFile.createMdiChild = function(fileName, nameFilter, uiFile, graphicsSceneCla
             errorCode = documentInterface.importFile(fileName, nameFilter);
         }
         if (errorCode !== RDocumentInterface.IoErrorNoError) {
-            var dialog = new QMessageBox(
-                QMessageBox.Warning,
-                qsTr("Import Error"),
-                "",
-                QMessageBox.OK
-            );
-            var path = fileName.elidedText(dialog.font, 500);
+            var dialog = undefined;
+            var path = fileName;
+            if (!silent) {
+                dialog = new QMessageBox(
+                    QMessageBox.Warning,
+                    qsTr("Import Error"),
+                    "",
+                    QMessageBox.OK
+                );
+                path = fileName.elidedText(dialog.font, 500);
+            }
             var text = qsTr("Cannot open file") + "\n\n'%1'.\n\n".arg(path);
             switch (errorCode) {
             case RDocumentInterface.IoErrorNoImporterFound:
@@ -186,11 +193,15 @@ NewFile.createMdiChild = function(fileName, nameFilter, uiFile, graphicsSceneCla
                 text += qsTr("File is empty.");
                 break;
             }
-            dialog.text = text;
             appWin.handleUserWarning(text);
-            dialog.exec();
-            dialog.destroy();
-            EAction.activateMainWindow();
+
+            if (!isNull(dialog)) {
+                dialog.text = text;
+                dialog.exec();
+                destr(dialog);
+                EAction.activateMainWindow();
+            }
+
             RSettings.removeRecentFile(fileName);
             return undefined;
         }
@@ -231,7 +242,7 @@ NewFile.createMdiChild = function(fileName, nameFilter, uiFile, graphicsSceneCla
     var mdiChild = new RMdiChildQt();
     mdiChild.windowIcon = new QIcon(autoPath("scripts/qcad_icon.png"));
     mdiChild.setDocumentInterface(documentInterface);
-    var flags = new Qt.WindowFlags(Qt.FramelessWindowHint);
+    var flags = makeQtWindowFlags(Qt.FramelessWindowHint);
     mdiChild.setWindowFlags(flags);
     mdiArea.addSubWindow(mdiChild);
     mdiChild.updatesEnabled = false;
@@ -254,9 +265,9 @@ NewFile.createMdiChild = function(fileName, nameFilter, uiFile, graphicsSceneCla
 
     RGuiAction.triggerGroupDefaults();
 
-    mdiChild.closeRequested.connect(NewFile, "closeRequested");
-    mdiChild.modifiedStatusChanged.connect(NewFile, "updateTitle");
-    appWin.resumedTab.connect(NewFile, "updateTitle");
+    mdiChild.closeRequested.connect(NewFile.closeRequested);
+    mdiChild.modifiedStatusChanged.connect(NewFile.updateTitle);
+    appWin.resumedTab.connect(NewFile.updateTitle);
 
     // make sure the MDI widget is maximized before performing an auto zoom:
 
@@ -299,7 +310,7 @@ NewFile.createMdiChild = function(fileName, nameFilter, uiFile, graphicsSceneCla
         for (k=0; k<NewFile.postNewActions.length; k++) {
             if (!isNull(NewFile.postNewActions[k])) {
                 include(NewFile.postNewActions[k]);
-                if (isFunction(initNewFile)) {
+                if (typeof(initNewFile)!=="undefined" && isFunction(initNewFile)) {
                     initNewFile(mdiChild);
                 }
                 action = RGuiAction.getByScriptFile(NewFile.postNewActions[k]);
@@ -331,7 +342,8 @@ NewFile.updateTitle = function(mdiChild) {
 
     var document = mdiChild.getDocument();
     var fileName = document.getFileName();
-    var title = undefined;
+    var title = "";
+    var titleAppWin = "";
 
     // untitled:
     if (fileName==="") {
@@ -344,15 +356,17 @@ NewFile.updateTitle = function(mdiChild) {
             documentCounter++;
             mdiChild.setWindowTitle(title);
         }
+        titleAppWin = mdiChild.windowTitle;
+        fileName = "Untitled.dxf";
     }
     else {
         var fi = new QFileInfo(fileName);
         var name = fi.fileName();
-        var roStr = qsTr("read-only");
         if (fi.isWritable()) {
             title = addDirtyFlag(name);
         }
         else {
+            var roStr = qsTr("read-only");
             title = name + " " + roStr;
         }
 
@@ -360,11 +374,20 @@ NewFile.updateTitle = function(mdiChild) {
         if (!isNull(tabBar)) {
             tabBar.setTabToolTip(tabBar.currentIndex, fileName);
         }
+        titleAppWin = title;
+        title = title.replace(/&/g, "&&");
         mdiChild.setWindowTitle(title);
     }
 
+    // TODO: implement proxy icon with drag and drop
+    // triggers QIconDragEvent
+    //if (RS.getSystemId()==="osx") {
+        //appWin.windowFilePath = fileName;
+        //appWin.windowModified = document.isModified();
+    //}
+
     appWin.setWindowTitle(
-        stripDirtyFlag(mdiChild.windowTitle) +
+        stripDirtyFlag(titleAppWin) +
         (document.isModified() ? " *" : "") +
         " - " + qApp.applicationName
     );
@@ -461,7 +484,7 @@ NewFile.closeRequested = function(mdiChild) {
     else {
         mdiChild.setCloseEventRejected();
     }
-    dialog.destroy();
+    destr(dialog);
     EAction.activateMainWindow();
 };
 
