@@ -41,7 +41,7 @@ Explode.initPreferences = function(pageWidget, calledByPrefDialog, document) {
         widgets["SplineTolerance"].visible = false;
         widgets["SplineTolerance_Label"].visible = false;
         widgets["SplinesToLineSegments"].visible = false;
-        widgets["Indent"].destroy();
+        destr(widgets["Indent"]);
         pageWidget.findChild("GridLayout").addWidget(widgets["SplineSegments_Label"], 2, 0, 1, 2);
     }
     else {
@@ -278,7 +278,18 @@ Explode.explodeEntity = function(entity, options) {
         if (RPolyline.hasProxy() && polyline.hasWidths()) {
 
             // list of polyline pairs (left / right):
-            var pls = polyline.getLeftRightOutline();
+            var pls;
+            if (RSettings.getQtVersion() >= 0x060000) {
+                pls = [];
+                var plsLeft = polyline.getLeftOutline();
+                var plsRight = polyline.getRightOutline();
+                for (var i=0; i<plsLeft.length && i<plsRight.length; i++) {
+                    pls.push([plsLeft[i], plsRight[i]]);
+                }
+            }
+            else {
+                pls = polyline.getLeftRightOutline();
+            }
 
             var first = true;
             var lastSegment = undefined;
@@ -601,6 +612,7 @@ Explode.explodeEntity = function(entity, options) {
     else if (isBlockReferenceEntity(entity)) {
         var data = entity.getData();
         var pos = entity.getPosition();
+        var uniform = RMath.fuzzyCompare(entity.getScaleFactors().x, entity.getScaleFactors().y);
 
         // explode array into multiple block references:
         if (data.getColumnCount()>1 || data.getRowCount()>1) {
@@ -637,6 +649,63 @@ Explode.explodeEntity = function(entity, options) {
                     continue;
                 }
 
+                // hatch in non-uniformly scaled block reference:
+                if (!uniform && isHatchEntity(subEntity)) {
+                    // query source entity from block (no transform):
+                    var untransformedSubEntity = data.queryEntity(subIds[k], false);
+
+                    // explode source entity:
+                    var untransformedEntitites = Explode.explodeEntity(untransformedSubEntity, options);
+
+                    var explodedHatchData = undefined;
+                    if (subEntity.isSolid()) {
+                        // solid hatch: create new solid hatch:
+                        explodedHatchData = new RHatchData();
+                        explodedHatchData.newLoop();
+                    }
+
+                    // transform by block transforms:
+                    for (var n=0; n<untransformedEntitites.length; n++) {
+                        var untransformedEntity = untransformedEntitites[n];
+
+                        if (isShape(untransformedEntity)) {
+                            untransformedEntity = shapeToEntity(document, untransformedEntity);
+                        }
+
+                        e = data.getTransformed(untransformedEntity);
+
+                        if (!isNull(explodedHatchData)) {
+                            // solid hatch: add transformed boundary to exploded hatch entity:
+                            explodedHatchData.addBoundary(e.castToShape());
+                        }
+                        else {
+                            // hatch pattern: add transformed entity:
+                            e.setSelected(true);
+                            if (isFunction(subEntity.data)) {
+                                e.copyAttributesFrom(getPtr(subEntity));
+                            }
+                            else {
+                                e.copyAttributesFrom(subEntity);
+                            }
+                            ret.push(e);
+                        }
+                    }
+
+                    if (!isNull(explodedHatchData)) {
+                        // solid hatch: add new solid hatch:
+                        e = new RHatchEntity(document, explodedHatchData);
+                        e.setSelected(true);
+                        if (isFunction(subEntity.data)) {
+                            e.copyAttributesFrom(getPtr(subEntity));
+                        }
+                        else {
+                            e.copyAttributesFrom(subEntity);
+                        }
+                        ret.push(e);
+                    }
+                    continue;
+                }
+
                 e = subEntity.clone();
                 //data.applyColumnRowOffsetTo(e, col, row);
                 // we need the old ID to update attribute parent IDs:
