@@ -1433,7 +1433,7 @@ ShapeAlgorithms.createCircleFrom3Points = function(point1, point2, point3) {
 
     var ret = RCircle.createFrom3Points(point1, point2, point3);
 
-    if (isNull(ret)) {
+    if (!ret.isValid()) {
         ShapeAlgorithms.error = qsTr("No circle possible.");
         return undefined;
     }
@@ -1739,6 +1739,10 @@ ShapeAlgorithms.splineToLineOrArc = function(spline, tolerance, linesOnly) {
  * Converts the given circle into an arc with the given start angle or 0.
  */
 ShapeAlgorithms.circleToArc = function(circle, startAngle) {
+    if (isNull(startAngle)) {
+        startAngle = 0.0;
+    }
+
     return circle.toArc(startAngle);
 };
 
