@@ -165,15 +165,14 @@ WidgetFactory.getKey = function(group, obj) {
     }
 
     var g = group;
-    if (typeof(obj["SettingsGroup"])!="undefined") {
-        g = obj["SettingsGroup"];
+    if (typeof(obj.property("SettingsGroup"))!="undefined") {
+        g = obj.property("SettingsGroup");
     }
     var key = [g, obj.objectName];
 
     // correct key:
     if (isOfType(obj, QRadioButton) || isOfType(obj, QToolButton)) {
         // correct to button group name:
-
         if (isFunction(obj.group) && !isNull(obj.group())) {
             key = [g, obj.group().objectName];
         }
@@ -254,6 +253,7 @@ WidgetFactory.saveState = function(widget, group, document, map) {
     for (var i = 0; i < children.length; ++i) {
         var c = children[i];
 
+
         if (!c || isDeleted(c) || c.toString().startsWith("QVariantAnimation") ||
                 c.toString().startsWith("QWidgetAction") || c.objectName==="" ||
                 c.objectName==="Icon" || c.objectName==="qt_toolbar_ext_button") {
@@ -377,7 +377,7 @@ WidgetFactory.saveState = function(widget, group, document, map) {
                 }
             }
         }
-        else if (c.toString().startsWith("RFontChooserWidget")) {
+        else if (isOfType(c, RFontChooserWidget)) {
             value = c.getChosenFont();
         }
 
@@ -410,7 +410,13 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         if (saveContents) {
             if (document) {
                 if (isObject(document)) {
-                    // save key / value pair to object:
+                    // make sure value of custom property is string, not QColor or RColor:
+                    // ensures that it can be stored in DXF/DWG and displayed in property editor:
+                    if (isOfType(value, QColor) || isOfType(value, RColor)) {
+                        value = value.name();
+                    }
+
+                    // save key / value pair to object (e.g. layout block):
                     document.setCustomProperty("QCAD", key, value);
                 }
                 else {
@@ -518,7 +524,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             value = c.property("defaultValue");
         } else {
             if (!isNull(map)) {
-                value = map.get(key);                
+                value = map.get(key);
             } else {
                 if (!isNull(document)) {
                     if (isObject(document)) {
@@ -706,7 +712,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
                 WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
                 if (value==="true") {
-                    c.checked = value;
+                    c.checked = true;
                 }
                 else {
                     c.checked = (c.objectName == value);
@@ -808,7 +814,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             if (!isNull(value)) {
                 index = -1;
                 if (forceSaveIndex == true) {
-                    index = value;
+                    index = parseInt(value);
                 }
                 else if (forceSaveText == false && hasData) {
                     index = c.findData(value);
@@ -1282,7 +1288,7 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
         menu.insertMenu(separatorAction, subMenu);
         menu.exec(QCursor.pos());
         if (!isDeleted(menu)) {
-            menu.destroy();
+            destr(menu);
         }
     });
 };
