@@ -62,21 +62,22 @@ function RBlockListQt(parent, addListener, showHeader) {
     this.setColumnWidth(BlockList.colVisible, 22);
     this.setColumnWidth(BlockList.colEdit, 22);
 
+    var self = this;
     if (addListener) {
         var appWin = EAction.getMainWindow();
         var adapter = new RBlockListenerAdapter();
         appWin.addBlockListener(adapter);
-        adapter.blocksUpdated.connect(this, "updateBlocks");
-        adapter.currentBlockSet.connect(this, "updateCurrentBlock");
-        adapter.blocksCleared.connect(this, "clearBlocks");
+        adapter.blocksUpdated.connect(function(di) { self.updateBlocks(di); });
+        adapter.currentBlockSet.connect(function(di) { self.updateCurrentBlock(di); });
+        adapter.blocksCleared.connect(function() { self.clearBlocks(); });
     }
 
-    this.itemDoubleClicked.connect(this, "editBlock");
-    this.itemColumnClicked.connect(this, "itemColumnClickedSlot");
-    this.itemSelectionChanged.connect(this, "blockActivated");
+    this.itemDoubleClicked.connect(function(item, col) { self.editBlock(item, col); });
+    this.itemColumnClicked.connect(function(item, col) { self.itemColumnClickedSlot(item, col); });
+    this.itemSelectionChanged.connect(function() { self.blockActivated(); });
     this.basePath = includeBasePath;
 
-    this.currentItem = undefined;
+    this.currentBlockItem = undefined;
 
 }
 
@@ -142,7 +143,7 @@ RBlockListQt.prototype.contextMenuEvent = function(e) {
 };
 
 RBlockListQt.complementContextMenu = function(menu, blockListWidget) {
-    // add addtional context menu actions provided by plugins:
+    // add additional context menu actions provided by plugins:
     var scriptFiles = RBlockListQt.getContextMenuScriptFiles(blockListWidget);
     for (var i=0; i<scriptFiles.length; i++) {
         var scriptFile = scriptFiles[i];
@@ -179,31 +180,31 @@ RBlockListQt.prototype.updateCurrentBlock = function(documentInterface) {
     var doc = documentInterface.getDocument();
 
     // find item which was representing the current block before:
-    if (!isNull(this.currentItem)) {
+    if (!isNull(this.currentBlockItem)) {
         // clear pen icon from item:
-        //var blockName = this.currentItem.data(BlockList.colName, Qt.UserRole);
+        //var blockName = this.currentBlockItem.data(BlockList.colName, Qt.UserRole);
         //var block = doc.queryBlock(blockName);
-        //this.updateItemIcons(this.currentItem, block);
-        this.currentItem.setIcon(BlockList.colEdit, BlockList.iconEdit[0]);
+        //this.updateItemIcons(this.currentBlockItem, block);
+        this.currentBlockItem.setIcon(BlockList.colEdit, BlockList.iconEdit[0]);
     }
 
     // find item of current block:
-    this.currentItem = RBlockListQt.getItem(this, doc.getCurrentBlockName());
+    this.currentBlockItem = RBlockListQt.getItem(this, doc.getCurrentBlockName());
     //for (var i=0; i<this.topLevelItemCount; i++) {
     //    var item = this.topLevelItem(i);
     //}
 
     // add pen icon to item:
-    if (!isNull(this.currentItem)) {
-        this.currentItem.setIcon(BlockList.colEdit, BlockList.iconEdit[1]);
+    if (!isNull(this.currentBlockItem)) {
+        this.currentBlockItem.setIcon(BlockList.colEdit, BlockList.iconEdit[1]);
     }
 };
 
 /**
- * Called when blocks are addded, edited or deleted. Updates the block list.
+ * Called when blocks are added, edited or deleted. Updates the block list.
  */
 RBlockListQt.prototype.updateBlocks = function(documentInterface) {
-    this.currentItem = undefined;
+    this.currentBlockItem = undefined;
 
     this.di = documentInterface;
 
@@ -230,7 +231,7 @@ RBlockListQt.prototype.updateBlocks = function(documentInterface) {
     for (i=0; i<blockCandidateIds.length; i++) {
         var blockCandidateId = blockCandidateIds[i];
         var blockCandidate = doc.queryBlockDirect(blockCandidateId);
-        if (blockCandidate.isNull()) {
+        if (isFunction(blockCandidate.isNull) && blockCandidate.isNull()) {
             continue;
         }
 
@@ -248,7 +249,7 @@ RBlockListQt.prototype.updateBlocks = function(documentInterface) {
     for (i=0; i<blockIds.length; ++i) {
         var blockId = blockIds[i];
         var block = doc.queryBlockDirect(blockId);
-        if (block.isNull()) {
+        if (isFunction(block.isNull) && block.isNull()) {
             continue;
         }
 
@@ -261,7 +262,7 @@ RBlockListQt.prototype.updateBlocks = function(documentInterface) {
         }
 
         if (currentBlockId===block.getId()) {
-            this.currentItem = item;
+            this.currentBlockItem = item;
         }
     }
 
@@ -293,7 +294,7 @@ RBlockListQt.prototype.createBlockItem = function(block) {
     var item = new QTreeWidgetItem();
     var name = block.getName();
 
-    var flags = new Qt.ItemFlags(Qt.ItemIsSelectable|Qt.ItemIsEnabled);
+    var flags = makeQtItemFlags(Qt.ItemIsSelectable, Qt.ItemIsEnabled);
     item.setFlags(flags);
 
     var title = RBlockListQt.getBlockTitle(block);
@@ -335,7 +336,7 @@ RBlockListQt.prototype.itemColumnClickedSlot = function(item, column) {
 
     var doc = this.di.getDocument();
     var block = doc.queryBlock(this.getBlockName(item));
-    if (block.isNull()) {
+    if (isFunction(block.isNull) && block.isNull()) {
         return;
     }
 
@@ -513,6 +514,16 @@ BlockList.getActiveItem = function() {
     return blockList.getActiveItem();
 };
 
+BlockList.getSelectedItems = function() {
+    var appWin = RMainWindowQt.getMainWindow();
+    var blockList = appWin.findChild("BlockList");
+    if (isNull(blockList)) {
+        return undefined;
+    }
+
+    return blockList.selectedItems();
+};
+
 /**
  * Shows / hides the block list.
  */
@@ -521,7 +532,7 @@ BlockList.prototype.beginEvent = function() {
 
     var appWin = RMainWindowQt.getMainWindow();
     var dock = appWin.findChild("BlockListDock");
-    if (!QCoreApplication.arguments().contains("-no-show")) {
+    if (!RSettings.getOriginalArguments().contains("-no-show")) {
         dock.visible = !dock.visible;
         if (dock.visible) dock.raise();
     }
@@ -554,9 +565,14 @@ BlockList.init = function(basePath) {
 
     var formWidget = WidgetFactory.createWidget(basePath, "BlockList.ui");
     var layout = formWidget.findChild("verticalLayout");
-    var blockList = new RBlockListQt(layout);
+    var blockList = new RBlockListQt(formWidget);
     blockList.objectName = "BlockList";
-    layout.addWidget(blockList, 1, 0);
+    if (RSettings.getQtVersion()>0x060000) {
+        layout.addWidget(blockList);
+    }
+    else {
+        layout.addWidget(blockList, 1, 0);
+    }
 
     RSettings.setValue("BlockList/AlternatingRowColor", new RColor(230, 235, 250), false);
     WidgetFactory.initList(blockList, "BlockList");
